pub struct RouterAdvertisementOptionWatcherProviderProxy { /* private fields */ }Implementations
Sourceimpl RouterAdvertisementOptionWatcherProviderProxy
impl RouterAdvertisementOptionWatcherProviderProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.net.ndp/RouterAdvertisementOptionWatcherProvider.
Sourcepub fn take_event_stream(
&self,
) -> RouterAdvertisementOptionWatcherProviderEventStream
pub fn take_event_stream( &self, ) -> RouterAdvertisementOptionWatcherProviderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn new_router_advertisement_option_watcher(
&self,
option_watcher: ServerEnd<OptionWatcherMarker>,
params: &RouterAdvertisementOptionWatcherParams,
) -> Result<(), Error>
pub fn new_router_advertisement_option_watcher( &self, option_watcher: ServerEnd<OptionWatcherMarker>, params: &RouterAdvertisementOptionWatcherParams, ) -> Result<(), Error>
Constructs a new watcher that yields NDP options received from router advertisement messages as described in RFC 4861 section 4.2.